==> tv_8.2201-2509122314.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/billing/QueryCustomerAccountInfoResponse.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.billing;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlType;


/**
 * <p>Java class for queryCustomerAccountInfoResponse complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="queryCustomerAccountInfoResponse">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}customerAccountInfo" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "queryCustomerAccountInfoResponse", propOrder = {
    "_return"
})
public class QueryCustomerAccountInfoResponse {

    @XmlElement(name = "return")
    protected CustomerAccountInfo _return;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link CustomerAccountInfo }
     *     
     */
    public CustomerAccountInfo getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link CustomerAccountInfo }
     *     
     */
    public void setReturn(CustomerAccountInfo value) {
        this._return = value;
    }

}

==> tv_10.2504-2601080422.zip: dyn/ru/bitel/bgbilling/modules/tv/dyn/cti/tve/ws/billing/QueryCustomerAccountInfoResponse.java <==

package ru.bitel.bgbilling.modules.tv.dyn.cti.tve.ws.billing;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlType;


/**
 * <p>Java class for queryCustomerAccountInfoResponse complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="queryCustomerAccountInfoResponse">
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element name="return" type="{http://ws.external.push.adapter.billing.integration.iptv.oss.cti.ru/}customerAccountInfo" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "queryCustomerAccountInfoResponse", propOrder = {
    "_return"
})
public class QueryCustomerAccountInfoResponse {

    @XmlElement(name = "return")
    protected CustomerAccountInfo _return;

    /**
     * Gets the value of the return property.
     * 
     * @return
     *     possible object is
     *     {@link CustomerAccountInfo }
     *     
     */
    public CustomerAccountInfo getReturn() {
        return _return;
    }

    /**
     * Sets the value of the return property.
     * 
     * @param value
     *     allowed object is
     *     {@link CustomerAccountInfo }
     *     
     */
    public void setReturn(CustomerAccountInfo value) {
        this._return = value;
    }

}
